==> nextcloud-28.0.3.tgz: nextcloud/apps/dav/l10n/hr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendar",
    "Tasks" : "Zadaci",
    "Personal" : "Osobno",
    "{actor} created calendar {calendar}" : "{actor} je stvorio kalendar {calendar}",
    "You created calendar {calendar}" : "Stvorili ste kalendar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} je izbrisao kalendar {calendar}",
    "You deleted calendar {calendar}" : "Izbrisali ste kalendar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} je ažurirao kalendar {calendar}",
    "You updated calendar {calendar}" : "Ažurirali ste kalendar {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} je vratio kalendar {calendar}",
    "You restored calendar {calendar}" : "Vratili ste kalendar {calendar}",
    "You shared calendar {calendar} as public link" : "Podijelili ste kalendar {calendar} putem javne poveznice",
    "You removed public link for calendar {calendar}" : "Uklonili ste javnu poveznicu na kalendar {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} dijeli kalendar {calendar} s vama",
    "You shared calendar {calendar} with {user}" : "Podijelili ste kalendar {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} dijeli kalendar {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} više ne dijeli kalendar {calendar} s vama",
    "You unshared calendar {calendar} from {user}" : "Više ne dijelite kalendar {calendar} s {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} više ne dijeli kalendar {calendar} s {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} više ne dijeli kalendar {calendar} sam sa sobom",
    "You shared calendar {calendar} with group {group}" : "Podijelili ste kalendar {kalendar} s grupom {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} dijeli kalendar {calendar} s grupom {group}",
    "You unshared calendar {calendar} from group {group}" : "Više ne dijelite kalendar {calendar} s grupom {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} više ne dijeli kalendar {calendar} s grupom {group}",
    "Untitled event" : "Događaj bez naslova",
    "{actor} created event {event} in calendar {calendar}" : "{actor} je stvorio događaj {event} u kalendaru {calendar}",
    "You created event {event} in calendar {calendar}" : "Stvorili ste događaj {event} u kalendaru {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} je izbrisao događaj {event} iz kalendara {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Izbrisali ste događaj {event} iz kalendara {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} je ažurirao događaj {event} u kalendaru {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ažurirali ste događaj {event} u kalendaru {calendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} je vratio događaj {event} kalendara {calendar}",
    "You restored event {event} of calendar {calendar}" : "Vratili ste događaj {event} kalendara {calendar}",
    "Busy" : "Zauzeto",
    "Calendar, contacts and tasks" : "Kalendar, kontakti i zadaci",
    "A <strong>calendar</strong> was modified" : "Izmijenjen je <strong>kalendar</strong>",
    "A calendar <strong>event</strong> was modified" : "Izmijenjen je <strong>događaj</strong> u kalendaru",
    "Contact birthdays" : "Rođendani kontakata",
    "Death of %s" : "Smrt %s",
    "Untitled calendar" : "Kalendar bez naslova",
    "Calendar:" : "Kalendar:",
    "Date:" : "Datum:",
    "Where:" : "Gdje:",
    "Description:" : "Opis:",
    "_%n year_::_%n years_" : ["%n godina","%n godina","%n godina"],
    "_%n month_::_%n months_" : ["%n mjesec","%n mjeseci","%n mjeseci"],
    "_%n day_::_%n days_" : ["%n dan","%n dana","%n dana"],
    "_%n hour_::_%n hours_" : ["%n sat","%n sati","%n sati"],
    "_%n minute_::_%n minutes_" : ["%n minute/minuta","%n minuta","%n minuta"],
    "%s (in %s)" : "%s (u %s)",
    "%s (%s ago)" : "%s (prije %s)",
    "Calendar: %s" : "Kalendar: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Gdje: %s",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Cancelled: %1$s" : "Otkazano: %1$s",
    "Re: %1$s" : "Odgovor: %1 $ s",
    "Invitation: %1$s" : "Pozivnica: %1$s",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Polaznici:",
    "Title:" : "Naslov:",
    "Time:" : "Vrijeme:",
    "Location:" : "Lokacija:",
    "Link:" : "Poveznica:",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "More options …" : "Više mogućnosti…",
    "More options at %s" : "Više mogućnosti na %s",
    "Contacts" : "Kontakti",
    "{actor} created address book {addressbook}" : "{actor} je stvorio adresar {addressbook}",
    "You created address book {addressbook}" : "Stvorili ste adresar {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} je izbrisao adresar {addressbook}",
    "You deleted address book {addressbook}" : "Izbrisali ste adresar {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} je ažurirao adresar {addressbook}",
    "You updated address book {addressbook}" : "Ažurirali ste adresar {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} dijeli adresar {addressbook} s vama",
    "You shared address book {addressbook} with {user}" : "Dijelite adresar {addressbook} s {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} dijeli adresar {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} je prestao dijeliti adresar {addressbook} s vama",
    "You unshared address book {addressbook} from {user}" : "Prestali ste dijeliti adresar {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} je prestao dijeliti adresar {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} je prestao dijeliti adresar {addressbook} sa sobom",
    "You shared address book {addressbook} with group {group}" : "Dijelite adresar {addressbook} s grupom {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} dijeli adresar {addressbook} s grupom {group}",
    "You unshared address book {addressbook} from group {group}" : "Prestali ste dijeliti adresar {addressbook} s grupom {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} je prestao dijeliti adresar {addressbook} s grupom {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} je stvorio kontakt {card} u adresaru {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Stvorili ste kontakt {card} u adresaru {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} je izbrisao kontakt {card} iz adresara {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Izbrisali ste kontakt {card} iz adresara {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} je ažurirao kontakt {card} u adresaru {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ažurirali ste kontakt {card} u adresaru {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Izmijenjen je <strong>kontakt</strong> ili <strong>adresar</strong>",
    "Accounts" : "Korisnićki računi",
    "System is in maintenance mode." : "Sustav je u načinu održavanja.",
    "Upgrade needed" : "Potrebno nadograditi",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Vaš %s treba konfigurirati za korištenje HTTPS-a kako bi se mogli upotrebljavati CalDAV i CardDAV s operacijskim sustavom iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurira CalDAV račun",
    "Configures a CardDAV account" : "Konfigurira CardDAV račun",
    "Events" : "Događaji",
    "Untitled task" : "Zadatak bez naslova",
    "Completed on %s" : "Završeno na %s",
    "Due on %s by %s" : "%s treba završiti do %s",
    "Due on %s" : "Treba završiti do %s",
    "Contacts and groups" : "Kontakti i grupe",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV krajnja točka",
    "Save" : "Spremi",
    "to" : "do",
    "Delete slot" : "Izbriši mjesto",
    "Add slot" : "Dodaj mjesto",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedjelja",
    "Availability" : "Raspoloživost",
    "Calendar server" : "Poslužitelj kalendara",
    "Send invitations to attendees" : "Pošaljite pozive sudionicima",
    "Automatically generate a birthday calendar" : "Automatski generiraj kalendar rođendana",
    "Birthday calendars will be generated by a background job." : "Kalendari rođendana generirat će se u pozadini.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Stoga neće biti dostupni odmah nakon omogućivanja, ali će se pojaviti nakon nekog vremena.",
    "Send notifications for events" : "Šalji obavijesti o događajima",
    "Notifications are sent via background jobs, so these must occur often enough." : "Obavijesti se šalju putem pozadinskih zadataka koji se moraju dovoljno često izvoditi.",
    "Enable notifications for events via push" : "Omogući slanje obavijesti o događajima putem push obavijesti",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Također instalirajte {calendarappstoreopen}aplikaciju Kalendar{linkclose} ili {calendardocopen}povežite računalo i mobilni uređaj radi sinkroniziranja ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Provjerite jeste li ispravno postavili {emailopen}poslužitelj e-pošte{linkclose}.",
    "There was an error updating your attendance status." : "Došlo je do pogreške prilikom ažuriranja statusa prisutnosti.",
    "Please contact the organizer directly." : "Izravno se obratite organizatoru.",
    "Are you accepting the invitation?" : "Prihvaćate li poziv?",
    "Tentative" : "Uvjetno",
    "Your attendance was updated successfully." : "Vaša je prisutnost uspješno ažurirana.",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ako konfigurirate svoje radno vrijeme, drugi korisnici moći će vidjeti jeste li izvan ureda kada rezerviraju sastanak."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-28.0.9.tgz: nextcloud/apps/dav/l10n/hr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendar",
    "Tasks" : "Zadaci",
    "Personal" : "Osobno",
    "{actor} created calendar {calendar}" : "{actor} je stvorio kalendar {calendar}",
    "You created calendar {calendar}" : "Stvorili ste kalendar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} je izbrisao kalendar {calendar}",
    "You deleted calendar {calendar}" : "Izbrisali ste kalendar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} je ažurirao kalendar {calendar}",
    "You updated calendar {calendar}" : "Ažurirali ste kalendar {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} je vratio kalendar {calendar}",
    "You restored calendar {calendar}" : "Vratili ste kalendar {calendar}",
    "You shared calendar {calendar} as public link" : "Podijelili ste kalendar {calendar} putem javne poveznice",
    "You removed public link for calendar {calendar}" : "Uklonili ste javnu poveznicu na kalendar {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} dijeli kalendar {calendar} s vama",
    "You shared calendar {calendar} with {user}" : "Podijelili ste kalendar {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} dijeli kalendar {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} više ne dijeli kalendar {calendar} s vama",
    "You unshared calendar {calendar} from {user}" : "Više ne dijelite kalendar {calendar} s {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} više ne dijeli kalendar {calendar} s {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} više ne dijeli kalendar {calendar} sam sa sobom",
    "You shared calendar {calendar} with group {group}" : "Podijelili ste kalendar {kalendar} s grupom {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} dijeli kalendar {calendar} s grupom {group}",
    "You unshared calendar {calendar} from group {group}" : "Više ne dijelite kalendar {calendar} s grupom {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} više ne dijeli kalendar {calendar} s grupom {group}",
    "Untitled event" : "Događaj bez naslova",
    "{actor} created event {event} in calendar {calendar}" : "{actor} je stvorio događaj {event} u kalendaru {calendar}",
    "You created event {event} in calendar {calendar}" : "Stvorili ste događaj {event} u kalendaru {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} je izbrisao događaj {event} iz kalendara {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Izbrisali ste događaj {event} iz kalendara {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} je ažurirao događaj {event} u kalendaru {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ažurirali ste događaj {event} u kalendaru {calendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} je vratio događaj {event} kalendara {calendar}",
    "You restored event {event} of calendar {calendar}" : "Vratili ste događaj {event} kalendara {calendar}",
    "Busy" : "Zauzeto",
    "Calendar, contacts and tasks" : "Kalendar, kontakti i zadaci",
    "A <strong>calendar</strong> was modified" : "Izmijenjen je <strong>kalendar</strong>",
    "A calendar <strong>event</strong> was modified" : "Izmijenjen je <strong>događaj</strong> u kalendaru",
    "Contact birthdays" : "Rođendani kontakata",
    "Death of %s" : "Smrt %s",
    "Untitled calendar" : "Kalendar bez naslova",
    "Calendar:" : "Kalendar:",
    "Date:" : "Datum:",
    "Where:" : "Gdje:",
    "Description:" : "Opis:",
    "_%n year_::_%n years_" : ["%n godina","%n godina","%n godina"],
    "_%n month_::_%n months_" : ["%n mjesec","%n mjeseci","%n mjeseci"],
    "_%n day_::_%n days_" : ["%n dan","%n dana","%n dana"],
    "_%n hour_::_%n hours_" : ["%n sat","%n sati","%n sati"],
    "_%n minute_::_%n minutes_" : ["%n minute/minuta","%n minuta","%n minuta"],
    "%s (in %s)" : "%s (u %s)",
    "%s (%s ago)" : "%s (prije %s)",
    "Calendar: %s" : "Kalendar: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Gdje: %s",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "Cancelled: %1$s" : "Otkazano: %1$s",
    "Re: %1$s" : "Odgovor: %1 $ s",
    "Invitation: %1$s" : "Pozivnica: %1$s",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Polaznici:",
    "Title:" : "Naslov:",
    "When:" : "Kada:",
    "Location:" : "Lokacija:",
    "Link:" : "Poveznica:",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "More options …" : "Više mogućnosti…",
    "More options at %s" : "Više mogućnosti na %s",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedjelja",
    "January" : "Siječanj",
    "February" : "Veljača",
    "March" : "Ožujak",
    "April" : "Travanj",
    "May" : "Svibanj",
    "June" : "Lipanj",
    "July" : "Srpanj",
    "August" : "Kolovoz",
    "September" : "Rujan",
    "October" : "Listopad",
    "November" : "Studeni",
    "December" : "Prosinac",
    "First" : "Prvi",
    "Last" : "Zadnji",
    "Contacts" : "Kontakti",
    "{actor} created address book {addressbook}" : "{actor} je stvorio adresar {addressbook}",
    "You created address book {addressbook}" : "Stvorili ste adresar {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} je izbrisao adresar {addressbook}",
    "You deleted address book {addressbook}" : "Izbrisali ste adresar {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} je ažurirao adresar {addressbook}",
    "You updated address book {addressbook}" : "Ažurirali ste adresar {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} dijeli adresar {addressbook} s vama",
    "You shared address book {addressbook} with {user}" : "Dijelite adresar {addressbook} s {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} dijeli adresar {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} je prestao dijeliti adresar {addressbook} s vama",
    "You unshared address book {addressbook} from {user}" : "Prestali ste dijeliti adresar {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} je prestao dijeliti adresar {addressbook} s {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} je prestao dijeliti adresar {addressbook} sa sobom",
    "You shared address book {addressbook} with group {group}" : "Dijelite adresar {addressbook} s grupom {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} dijeli adresar {addressbook} s grupom {group}",
    "You unshared address book {addressbook} from group {group}" : "Prestali ste dijeliti adresar {addressbook} s grupom {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} je prestao dijeliti adresar {addressbook} s grupom {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} je stvorio kontakt {card} u adresaru {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Stvorili ste kontakt {card} u adresaru {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} je izbrisao kontakt {card} iz adresara {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Izbrisali ste kontakt {card} iz adresara {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} je ažurirao kontakt {card} u adresaru {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ažurirali ste kontakt {card} u adresaru {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Izmijenjen je <strong>kontakt</strong> ili <strong>adresar</strong>",
    "Accounts" : "Korisnićki računi",
    "System is in maintenance mode." : "Sustav je u načinu održavanja.",
    "Upgrade needed" : "Potrebno nadograditi",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Vaš %s treba konfigurirati za korištenje HTTPS-a kako bi se mogli upotrebljavati CalDAV i CardDAV s operacijskim sustavom iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurira CalDAV račun",
    "Configures a CardDAV account" : "Konfigurira CardDAV račun",
    "Events" : "Događaji",
    "Untitled task" : "Zadatak bez naslova",
    "Completed on %s" : "Završeno na %s",
    "Due on %s by %s" : "%s treba završiti do %s",
    "Due on %s" : "Treba završiti do %s",
    "WebDAV endpoint" : "WebDAV krajnja točka",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vaš mrežni poslužitelj nije pravilno podešen za sinkronizaciju podataka jer je sučelje protokola WebDAV neispravno.",
    "Contacts and groups" : "Kontakti i grupe",
    "WebDAV" : "WebDAV",
    "Save" : "Spremi",
    "to" : "do",
    "Delete slot" : "Izbriši mjesto",
    "Add slot" : "Dodaj mjesto",
    "Availability" : "Raspoloživost",
    "Calendar server" : "Poslužitelj kalendara",
    "Send invitations to attendees" : "Pošaljite pozive sudionicima",
    "Automatically generate a birthday calendar" : "Automatski generiraj kalendar rođendana",
    "Birthday calendars will be generated by a background job." : "Kalendari rođendana generirat će se u pozadini.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Stoga neće biti dostupni odmah nakon omogućivanja, ali će se pojaviti nakon nekog vremena.",
    "Send notifications for events" : "Šalji obavijesti o događajima",
    "Notifications are sent via background jobs, so these must occur often enough." : "Obavijesti se šalju putem pozadinskih zadataka koji se moraju dovoljno često izvoditi.",
    "Enable notifications for events via push" : "Omogući slanje obavijesti o događajima putem push obavijesti",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Također instalirajte {calendarappstoreopen}aplikaciju Kalendar{linkclose} ili {calendardocopen}povežite računalo i mobilni uređaj radi sinkroniziranja ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Provjerite jeste li ispravno postavili {emailopen}poslužitelj e-pošte{linkclose}.",
    "There was an error updating your attendance status." : "Došlo je do pogreške prilikom ažuriranja statusa prisutnosti.",
    "Please contact the organizer directly." : "Izravno se obratite organizatoru.",
    "Are you accepting the invitation?" : "Prihvaćate li poziv?",
    "Tentative" : "Uvjetno",
    "Your attendance was updated successfully." : "Vaša je prisutnost uspješno ažurirana.",
    "Time:" : "Vrijeme:",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ako konfigurirate svoje radno vrijeme, drugi korisnici moći će vidjeti jeste li izvan ureda kada rezerviraju sastanak."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
